//
//  SCAdController.h
//  Spotx_sdk_ios
//
//  Copyright © 2019 smartclip. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "SCAdFacadeDelegate.h"
#import "SCAdListener.h"
#import "SCAdMacros.h"

NS_ASSUME_NONNULL_BEGIN
@class SCAdContentView, SCAdListener;
@protocol SCAdSessionStateListener;

/**
 * The SCAdController encapsulates video playback for
 * the outstream use case
 */
@interface SCAdController : NSObject
/// Set the SCAdListener delegate here
@property (nonatomic, weak) id<SCAdListener> delegate;
/// Initialize this controller with your session state listener
- (instancetype)initWithSessionStateListener:(id<SCAdSessionStateListener>)sessionStateListener;
/// Set the adContentView
- (void)setContentView:(SCAdContentView*)contentView;
/// Call this function to start an adSlot with a certain configuration
- (void)startAdSlotWith:(SCAdConfiguration*)configuration;
/// Call this function to stop an adSlot before it is finished by itself
- (void)stopAdSlot;
/// Get your detailed adInfo object here
- (void)getAdInfo:(SCAdInfoCompletionBlock)completion;
/// Get a detailed adError description here
- (void)getAdError:(SCAdErrorCompletionBlock)completion;
/// Get your publicAdSlot object here
- (void)getPublicAdSlot:(SCPublicAdSlotCompletionBlock)completion;
/// Pause playback of the ad
- (void)pausePlayback;
/// Start playback of the ad
- (void)startPlayback;
/// Find out if playback is currently paused.
- (BOOL)isPaused;

/// :nodoc:
- (void)setOmidEventLoggingDelegate:(id<SCOmidEventLoggingDelegate>)omidEventLogger;
@end

NS_ASSUME_NONNULL_END
